Molecular weight
================

Functions to calculate molecular weight of an element, compound, or gas mixture.
Note that mole fractions must sum to one otherwise an error is raised.

.. autofunction:: chemics.molecular_weight
